@@ -4,5 +4,5 @@
 import os.path as osp
 
 HERE = osp.join(osp.abspath(osp.dirname(__file__)))
-FRENCH_LEMMAS = dict([t.strip().split('\t')
-                      for t in open(osp.join(HERE, 'french_lemmas.txt'))])
+with open(osp.join(HERE, "french_lemmas.txt")) as fobj:
+    FRENCH_LEMMAS = dict(t.strip().split("\t") for t in fobj)
