@@ -23,13 +23,13 @@ from os import path
 
 import numpy as np
 
-# Make sure tests are repeatable
-random.seed(6)  # noqa
-
 import nazca.rl.aligner as alig
 import nazca.rl.blocking as blo
 from nazca.utils.distances import LevenshteinProcessing, GeographicalProcessing
 
+# Make sure tests are repeatable
+random.seed(6)
+
 
 TESTDIR = path.dirname(__file__)
 
