@@ -21,9 +21,6 @@ from os import path
 from functools import partial
 import random
 
-# Make sure tests are repeatable / Minhashing
-random.seed(6)  # noqa
-
 from nazca.utils.distances import soundexcode
 from nazca.rl.blocking import (
     KeyBlocking,
@@ -39,6 +36,9 @@ from nazca.rl.blocking import (
 from nazca.utils.normalize import SimplifyNormalizer
 from nazca.data import FRENCH_LEMMAS
 
+# Make sure tests are repeatable / Minhashing
+random.seed(6)
+
 
 TESTDIR = path.dirname(__file__)
 
