@@ -20,9 +20,6 @@ import unittest
 import random
 from dateutil import parser as dateparser
 
-# Make sure tests are repeatable
-random.seed(6)  # noqa
-
 from nazca.utils.distances import (
     levenshtein,
     soundex,
@@ -40,6 +37,9 @@ from nazca.utils.distances import (
     DATEUTIL_ENABLED,
 )
 
+# Make sure tests are repeatable
+random.seed(6)
+
 
 class DistancesTest(unittest.TestCase):
     def test_difflib_match(self):
